###########################################################################
#
# PowerPointPlugin.pm -- plugin for importing Microsoft PowerPoint files.
#  (currently only versions 95 and 97)
#
# A component of the Greenstone digital library software
# from the New Zealand Digital Library Project at the 
# University of Waikato, New Zealand.
#
# Copyright (C) 2002 New Zealand Digital Library Project
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
###########################################################################

package PowerPointPlugin;

use ConvertBinaryFile;

use strict;
no strict 'refs'; # allow filehandles to be variables and viceversa

sub BEGIN {
    @PowerPointPlugin::ISA = ('ConvertBinaryFile');
}

my $convert_to_list =
    [ {	'name' => "auto",
	'desc' => "{ConvertBinaryFile.convert_to.auto}" },
      {	'name' => "html",
	'desc' => "{ConvertBinaryFile.convert_to.html}" },
      {	'name' => "text",
	'desc' => "{ConvertBinaryFile.convert_to.text}" },
      { 'name' => "pagedimg_jpg",
	'desc' => "{ConvertBinaryFile.convert_to.pagedimg_jpg}" },
      { 'name' => "pagedimg_gif",
	'desc' => "{ConvertBinaryFile.convert_to.pagedimg_gif}" },
      { 'name' => "pagedimg_png",
	'desc' => "{ConvertBinaryFile.convert_to.pagedimg_png}" }
      ];

my $arguments = 
    [ { 'name' => "process_exp",
	'desc' => "{BasePlugin.process_exp}",
	'type' => "regexp",
	'reqd' => "no",
	'deft' => &get_default_process_exp()}
      ];

my $options = { 'name'     => "PowerPointPlugin",
		'desc'     => "{PPTPlugin.desc}",
		'abstract' => "no",
		'inherits' => "yes",
		'srcreplaceable' => "yes", # Source docs in PPT format can be replaced with GS-generated html
	        'args'     => $arguments };

sub new {
    my ($class) = shift (@_);
    my ($pluginlist,$inputargs,$hashArgOptLists) = @_;
    push(@$pluginlist, $class);

    if ($ENV{'GSDLOS'} =~ m/^windows$/i) {
	my $ws_arg =[{ 'name' => "convert_to",
		       'desc' => "{ConvertBinaryFile.convert_to}",
		       'type' => "enum",
		       'reqd' => "yes",
		       'list' => $convert_to_list, 
		       'deft' => "html" },
		     { 'name' => "windows_scripting",
		       'desc' => "{PPTPlugin.windows_scripting}",
		       'type' => "flag",
		       'reqd' => "no" }
		     ];
	push(@$arguments,@$ws_arg);
    }
    
    push(@{$hashArgOptLists->{"ArgList"}},@{$arguments});
    push(@{$hashArgOptLists->{"OptList"}},$options);


    my $self = new ConvertBinaryFile($pluginlist, $inputargs, $hashArgOptLists);
 
    if ($self->{'info_only'}) {
	# don't worry about any options etc
	return bless $self, $class;
    }

    $self->{'filename_extension'} = "ppt";
    $self->{'file_type'} = "PPT";

    # ppthtml outputs utf-8 already.
    #these are passed through to gsConvert.pl by ConvertBinaryFile.pm
    $self->{'convert_options'} = "-windows_scripting" if $self->{'windows_scripting'};
    my $secondary_plugin_options = $self->{'secondary_plugin_options'};

    if ($self->{'windows_scripting'} && ($self->{'convert_to'} eq "PagedImg")) {
	$secondary_plugin_options->{'PagedImagePlugin'} = [];
    } else {
	$secondary_plugin_options->{'HTMLPlugin'} = [];
    }
    my $html_options = $secondary_plugin_options->{'HTMLPlugin'};
    my $pageimg_options = $secondary_plugin_options->{'PagedImagePlugin'};
 
    if (defined $secondary_plugin_options->{'HTMLPlugin'}){
	push(@$html_options,"-input_encoding", "utf8");
	push(@$html_options,"-extract_language") if $self->{'extract_language'};
	
	# Instruct HTMLPlugin (when eventually accessed through read_into_doc_obj) 
	# to extract these metadata fields from the HEAD META fields
	push(@$html_options,"-metadata_fields","Title,GENERATOR,date,author<Creator>");
    } 
    if (defined $secondary_plugin_options->{'PagedImagePlugin'}){
	push(@$pageimg_options,"-input_encoding", "utf8");
	push(@$pageimg_options,"-extract_language") if $self->{'extract_language'};
    }

    $self = bless $self, $class;

    $self->load_secondary_plugins($class,$secondary_plugin_options,$hashArgOptLists);
    return $self;
}

sub get_default_process_exp {
    my $self = shift (@_);
    return q^(?i)\.ppt$^;
}

1;

